<?php
  /* vim: set expandtab tabstop=4 softtabstop=4 shiftwidth=4:
  Codificación: UTF-8
  +----------------------------------------------------------------------+
  | Elastix version 2.4.0-13                                               |
  | http://www.elastix.org                                               |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006 Palosanto Solutions S. A.                         |
  +----------------------------------------------------------------------+
  | Cdla. Nueva Kennedy Calle E 222 y 9na. Este                          |
  | Telfs. 2283-268, 2294-440, 2284-356                                  |
  | Guayaquil - Ecuador                                                  |
  | http://www.palosanto.com                                             |
  +----------------------------------------------------------------------+
  | The contents of this file are subject to the General Public License  |
  | (GPL) Version 2 (the "License"); you may not use this file except in |
  | compliance with the License. You may obtain a copy of the License at |
  | http://www.opensource.org/licenses/gpl-license.php                   |
  |                                                                      |
  | Software distributed under the License is distributed on an "AS IS"  |
  | basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See  |
  | the License for the specific language governing rights and           |
  | limitations under the License.                                       |
  +----------------------------------------------------------------------+
  | The Original Code is: Elastix Open Source.                           |
  | The Initial Developer of the Original Code is PaloSanto Solutions    |
  +----------------------------------------------------------------------+
  $Id: index.php,v 1.1 2014-04-28 08:04:37 Alberto Santos asantos@palosanto.com Exp $ */
//include elastix framework
require_once "libs/ccproForm.class.php";

function _moduleContent(&$smarty, $module_name)
{
    //include module files
    include_once "modules/$module_name/configs/default.conf.php";

    //include file language agree to elastix configuration
    //if file language not exists, then include language by default (en)
    $lang=get_language();
    $base_dir=dirname($_SERVER['SCRIPT_FILENAME']);
    $lang_file="modules/$module_name/lang/$lang.lang";
    if (file_exists("$base_dir/$lang_file")) include_once "$lang_file";
    else include_once "modules/$module_name/lang/en.lang";

    //global variables
    global $arrConf;
    global $arrConfModule;
    global $arrLang;
    global $arrLangModule;
    $arrConf = array_merge($arrConf,$arrConfModule);
    $arrLang = array_merge($arrLang,$arrLangModule);

    //folder path for custom templates
    $templates_dir=(isset($arrConf['templates_dir']))?$arrConf['templates_dir']:'themes';
    $local_templates_dir="$base_dir/modules/$module_name/".$templates_dir.'/'.$arrConf['theme'];

    //actions
    $action = getAction();

    switch($action){
        case "save_license":
            $content = saveCCPRO_License($smarty, $module_name, $local_templates_dir, $pDB, $arrConf, $lang);
            break;
        default: // view_form
            $content = viewFormCCPRO_About($smarty, $module_name, $local_templates_dir, $pDB, $arrConf, $lang);
            break;
    }
    return $content;
}

function viewFormCCPRO_About($smarty, $module_name, $local_templates_dir, &$pDB, $arrConf, $lang)
{
    $oForm = new ccproForm($smarty,array());

    $oForm->addHtml(_tr("Elastix Call Center PRO version 1.0.0-1"));

    $smarty->assign("UPLOAD", _tr("Upload License"));
    $smarty->assign("MODULE_NAME", $module_name);
    $smarty->assign('ccpro_title', _tr("About us"));
    $smarty->assign("LABEL_LICENSE", _tr("License File"));
    $smarty->assign("SEARCH", _tr("Select File"));

    if($lang == "es")
    	$smarty->assign("LINK", "http://elastix.org/index.php/es/call-center-pro-form.html");
    else
	$smarty->assign("LINK", "http://elastix.org/index.php/en/call-center-pro-form.html");

    $smarty->assign("CONTENT_ABOUT","<p>"._tr("Elastix &reg; Call Center PRO is a powerful, robust, flexible, and easy to use solution, which redefines real-time collaboration for a Call Center. For more information about the product and its features, please visit: <a href='http://elx.ec/callcenterpro'>http://elx.ec/callcenterpro</a>")."</p><p>"._tr("We have the call center option you need. Learn about our different plans and available options through our regional office that is closest to you.")."</p><p>"._tr("Please complete the below form below and one of our agents will get in touch with you.")."</p>");

    $smarty->assign("FORM_LINK",_tr("OBTAIN YOUR LICENSE KEY BY CONTACTING US"));
    $smarty->assign("COPYRIGHT","&copy; ".date("Y")." "._tr("Elastix. All rights reserved"));

    $htmlForm = $oForm->fetchForm("$local_templates_dir/form.tpl",_tr("About us"));
    $content = "<form  method='POST' enctype='multipart/form-data' style='margin-bottom:0;' action='?menu=$module_name'>".$htmlForm."</form>";

    return $content;
}

function saveCCPRO_License($smarty, $module_name, $local_templates_dir, &$pDB, $arrConf, $lang)
{
    if(empty($_FILES["license_file"]["name"])){
	$smarty->assign("mb_title", _tr("ERROR"));
        $smarty->assign("mb_message", _tr("Please. Upload a license file"));
    }
    elseif(!preg_match("/^elastix-callcenterpro\.lic$/",$_FILES["license_file"]["name"])){
        $smarty->assign("mb_title", _tr("ERROR"));
        $smarty->assign("mb_message", _tr("Invalid license file name. The name must be elastix-callcenterpro.lic"));
    }
    elseif(!is_uploaded_file($_FILES['license_file']['tmp_name'])){
	$smarty->assign("mb_title", _tr("ERROR"));
        $smarty->assign("mb_message", _tr('Possible file upload attack. Filename') ." :". $_FILES['license_file']['name']);
    }
    else{
	exec('/usr/bin/elastix-helper ccproLicense '.escapeshellarg($_FILES['license_file']['tmp_name']),$output,$ret);
	if($ret != 0){
		$smarty->assign("mb_title", _tr("ERROR"));
		$smarty->assign("mb_message", _tr($output[0]));
	}
	else{
		$smarty->assign("mb_title", _tr("Message"));
        	$smarty->assign("mb_message", _tr("License successfully saved"));
	}
    }

    return viewFormCCPRO_About($smarty, $module_name, $local_templates_dir, $pDB, $arrConf, $lang);
}

function getAction()
{
    if(getParameter("save_license")) //Get parameter by POST (submit)
        return "save_license";
    else
        return "report"; //cancel
}
?>
